Name:		firewalld
Version:	0.6.3
Release:	0%{?dist}.1
Summary:	A firewall daemon with D-Bus interface providing a dynamic firewall
Group:          System/Servers
License:	GPLv2+
URL:		https://www.firewalld.org
Source0:	https://github.com/firewalld/firewalld/archive/v%{version}/%{name}-%{version}.tar.gz
BuildArch:	noarch
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	intltool
BuildRequires:	gettext
BuildRequires:	desktop-file-utils
BuildRequires:	systemd
BuildRequires:	docbook-style-xsl
BuildRequires:	xsltproc
BuildRequires:	pkgconfig(python3)
BuildRequires:	iptables
BuildRequires:	ipset
BuildRequires:	ebtables
BuildRequires:	nftables >= 0.9.0

Requires:	iptables
Requires:	ipset
Requires:	ebtables
Requires:	nftables >= 0.9.0
Requires:	firewalld-filesystem = %{version}-%{release}
Requires:	python3-firewall = %{version}-%{release}
%{?systemd_requires}

%description
Firewalld provides a dynamically managed firewall with support for
network/firewall zones that define the trust level of network
connections or interfaces. It has support for IPv4, IPv6 firewall
settings, ethernet bridges and IP sets. There is a separation of
runtime and permanent configuration options. It also provides an
interface for services or applications to add firewall rules directly.

%package -n python3-firewall
Summary:	Python3 bindings for firewalld
Group:		Development/Python
%{?python_provide:%python_provide python3-firewall}
Requires:	python3-dbus
Requires:	python3-slip-dbus
Requires:	python3-decorator
Requires:	python3-gobject3

%description -n python3-firewall
Python3 bindings for firewalld.

%package -n firewalld-filesystem
Summary:	Firewalld directory layout and rpm macros
Group:          System/Servers

%description -n firewalld-filesystem
This package provides directories and rpm macros which are required by
other packages that add firewalld configuration files.

%package -n firewall-applet
Summary:	Firewall panel applet
Group:          System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	firewall-config = %{version}-%{release}
Requires:	python3-gobject3
Requires:	libnotify
Requires:	dbus-x11
Requires:       python3-qt5-core
Requires:       python3-qt5-gui
Requires:       python3-qt5-widgets

%description -n firewall-applet
The firewall panel applet provides a status information of firewalld as
well as the settings of the firewall.

%package -n firewall-config
Summary:	Firewall configuration application
Group:          System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	python3-gobject3
Requires:	dbus-x11

%description -n firewall-config
The firewall configuration application provides a configuration interface
for firewalld.

%prep
%autosetup -p1
./autogen.sh

%build
%configure2_5x --enable-sysconfig --enable-rpmmacros PYTHON=%{__python3}
%make_build

%install
%make_install PYTHON=%{__python3}

desktop-file-install --delete-original \
  --dir %{buildroot}%{_sysconfdir}/xdg/autostart \
  %{buildroot}%{_sysconfdir}/xdg/autostart/firewall-applet.desktop
desktop-file-install --delete-original \
  --dir %{buildroot}%{_datadir}/applications \
  %{buildroot}%{_datadir}/applications/firewall-config.desktop

%find_lang %{name} --all-name

# Move modprobe.d config to /usr/lib
mv %{buildroot}%{_sysconfdir}/modprobe.d %{buildroot}%{_prefix}/lib

%post
%systemd_post firewalld.service

%preun
%systemd_preun firewalld.service

%postun
%systemd_postun_with_restart firewalld.service


%files -f %{name}.lang
%doc README
%license COPYING
%{_sbindir}/firewalld
%{_bindir}/firewall-cmd
%{_bindir}/firewall-offline-cmd
%{_datadir}/bash-completion/completions/firewall-cmd
%{_prefix}/lib/firewalld/helpers/*.xml
%{_prefix}/lib/firewalld/icmptypes/*.xml
%{_prefix}/lib/firewalld/ipsets/README
%{_prefix}/lib/firewalld/services/*.xml
%{_prefix}/lib/firewalld/zones/*.xml
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld
%config(noreplace) %{_sysconfdir}/firewalld/firewalld.conf
%config(noreplace) %{_sysconfdir}/firewalld/lockdown-whitelist.xml
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/icmptypes
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/services
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/zones
%config(noreplace) %{_sysconfdir}/sysconfig/firewalld
%{_unitdir}/firewalld.service
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/FirewallD.conf
%{_datadir}/polkit-1/actions/org.fedoraproject.FirewallD1.desktop.policy.choice
%{_datadir}/polkit-1/actions/org.fedoraproject.FirewallD1.server.policy.choice
%{_datadir}/polkit-1/actions/org.fedoraproject.FirewallD1.policy
%{_mandir}/man1/firewall*.1.*
%{_mandir}/man5/firewall*.5*
%{_prefix}/lib/modprobe.d/firewalld-sysctls.conf

%files -n python3-firewall
%attr(0755,root,root) %dir %{python3_sitelib}/firewall
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/__pycache__
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/config
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/config/__pycache__
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core/__pycache__
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core/io
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core/io/__pycache__
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/server
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/server/__pycache__
%{python3_sitelib}/firewall/__pycache__/*.py*
%{python3_sitelib}/firewall/*.py*
%{python3_sitelib}/firewall/config/*.py*
%{python3_sitelib}/firewall/config/__pycache__/*.py*
%{python3_sitelib}/firewall/core/*.py*
%{python3_sitelib}/firewall/core/__pycache__/*.py*
%{python3_sitelib}/firewall/core/io/*.py*
%{python3_sitelib}/firewall/core/io/__pycache__/*.py*
%{python3_sitelib}/firewall/server/*.py*
%{python3_sitelib}/firewall/server/__pycache__/*.py*

%files -n firewalld-filesystem
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/helpers
%dir %{_prefix}/lib/firewalld/icmptypes
%dir %{_prefix}/lib/firewalld/services
%dir %{_prefix}/lib/firewalld/zones
%{_rpmconfigdir}/macros.d/macros.firewalld

%files -n firewall-applet
%{_bindir}/firewall-applet
%{_sysconfdir}/xdg/autostart/firewall-applet.desktop
%dir %{_sysconfdir}/firewall
%{_sysconfdir}/firewall/applet.conf
%{_datadir}/icons/hicolor/*/apps/firewall-applet*.*
%{_mandir}/man1/firewall-applet*.1*

%files -n firewall-config
%{_bindir}/firewall-config
%{_datadir}/firewalld/firewall-config.glade
%{_datadir}/firewalld/gtk3_chooserbutton.py*
%{_datadir}/firewalld/gtk3_niceexpander.py*
%{_datadir}/applications/firewall-config.desktop
%{_datadir}/metainfo/firewall-config.appdata.xml
%{_datadir}/icons/hicolor/*/apps/firewall-config*.*
%{_datadir}/glib-2.0/schemas/org.fedoraproject.FirewallConfig.gschema.xml
%{_mandir}/man1/firewall-config*.1*

%changelog
* Sat Feb 23 07:25:31 EST 2019 Neal Gompa <ngompa@mageia.org>
- Build for COPR

* Sat Feb 23 2019 Neal Gompa <ngompa@mageia.org> 0.6.3-1.mga6
+ Revision: 1369539
- Rebase to 0.6.3

* Tue Jan 08 2019 Shlomi Fish <shlomif@mageia.org> 0.4.4.3-8.mga7
+ Revision: 1352788
- Rebuild for python3 3.7

* Wed Sep 19 2018 Sysadmin Bot <umeabot@mageia.org> 0.4.4.3-7.mga7
+ Revision: 1278238
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 Jani Välimaa <wally@mageia.org> 0.4.4.3-6.mga7
+ Revision: 1248829
- add pycache back

* Fri Jul 06 2018 David GEIGER <daviddavid@mageia.org> 0.4.4.3-5.mga7
+ Revision: 1242172
- update files list (no more __pycache__ reference)

* Sat Aug 05 2017 Pascal Terjan <pterjan@mageia.org> 0.4.4.3-4.mga7
+ Revision: 1135210
- Rebuild for python 3.6

* Fri Feb 17 2017 Nicolas Lécureuil <neoclust@mageia.org> 0.4.4.3-3.mga6
+ Revision: 1086601
- add more strict python3-qt5-<module> requires for applet (thx to wally)

* Fri Feb 17 2017 Nicolas Lécureuil <neoclust@mageia.org> 0.4.4.3-2.mga6
+ Revision: 1086600
- Add python3-qt5 as applet requires (thx to wally)

* Fri Feb 17 2017 Nicolas Lécureuil <neoclust@mageia.org> 0.4.4.3-1.mga6
+ Revision: 1086560
- New version 0.4.4.3

* Mon Feb 13 2017 Nicolas Lécureuil <neoclust@mageia.org> 0.4.4.2-1.mga6
+ Revision: 1086032
- imported package firewalld
